==> qt6-webengine-6.2.1-1-aarch64.pkg.tar.xz: usr/include/qt6/QtWebEngineCore/6.2.1/QtWebEngineCore/private/qwebengineprofile_p.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWebEngine module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QWEBENGINEPROFILE_P_H
#define QWEBENGINEPROFILE_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "profile_adapter_client.h"

#include <QMap>
#include <QPointer>
#include <QScopedPointer>
#include <QSharedPointer>

#include <functional>

namespace QtWebEngineCore {
class ProfileAdapter;
}

QT_BEGIN_NAMESPACE

class QWebEngineNotification;
class QWebEngineProfile;
class QWebEngineScriptCollection;
class QWebEngineSettings;

class Q_WEBENGINECORE_PRIVATE_EXPORT QWebEngineProfilePrivate : public QtWebEngineCore::ProfileAdapterClient {
public:
    Q_DECLARE_PUBLIC(QWebEngineProfile)
    QWebEngineProfilePrivate(QtWebEngineCore::ProfileAdapter *profileAdapter);
    ~QWebEngineProfilePrivate();

    QtWebEngineCore::ProfileAdapter *profileAdapter() const;
    QWebEngineSettings *settings() const { return m_settings; }

    void downloadDestroyed(quint32 downloadId);

    void cleanDownloads();

    void downloadRequested(DownloadItemInfo &info) override;
    void downloadUpdated(const DownloadItemInfo &info) override;

    void showNotification(QSharedPointer<QtWebEngineCore::UserNotificationController> &) override;

    void addWebContentsAdapterClient(QtWebEngineCore::WebContentsAdapterClient *adapter) override;
    void removeWebContentsAdapterClient(QtWebEngineCore::WebContentsAdapterClient *adapter) override;

private:
    QWebEngineProfile *q_ptr;
    QWebEngineSettings *m_settings;
    QPointer<QtWebEngineCore::ProfileAdapter> m_profileAdapter;
    QScopedPointer<QWebEngineScriptCollection> m_scriptCollection;
    QMap<quint32, QPointer<QWebEngineDownloadRequest>> m_ongoingDownloads;
    std::function<void(std::unique_ptr<QWebEngineNotification>)> m_notificationPresenter;
};

QT_END_NAMESPACE

#endif // QWEBENGINEPROFILE_P_H

==> qt6-webengine-6.7.2-3-aarch64.pkg.tar.xz: usr/include/qt6/QtWebEngineCore/6.7.2/QtWebEngineCore/private/qwebengineprofile_p.h <==
// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QWEBENGINEPROFILE_P_H
#define QWEBENGINEPROFILE_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "profile_adapter_client.h"

#include <QMap>
#include <QPointer>
#include <QScopedPointer>
#include <QSharedPointer>

#include <functional>

namespace QtWebEngineCore {
class ProfileAdapter;
class WebEngineSettings;
}

QT_BEGIN_NAMESPACE

class QWebEngineNotification;
class QWebEngineProfile;
class QWebEngineScriptCollection;
class QWebEngineSettings;

class Q_WEBENGINECORE_PRIVATE_EXPORT QWebEngineProfilePrivate : public QtWebEngineCore::ProfileAdapterClient {
public:
    Q_DECLARE_PUBLIC(QWebEngineProfile)
    QWebEngineProfilePrivate(QtWebEngineCore::ProfileAdapter *profileAdapter);
    ~QWebEngineProfilePrivate();

    QtWebEngineCore::ProfileAdapter *profileAdapter() const;
    QWebEngineSettings *settings() const { return m_settings; }
    QtWebEngineCore::WebEngineSettings *coreSettings() const override;

    void downloadDestroyed(quint32 downloadId);

    void cleanDownloads();

    void downloadRequested(DownloadItemInfo &info) override;
    void downloadUpdated(const DownloadItemInfo &info) override;

    void showNotification(QSharedPointer<QtWebEngineCore::UserNotificationController> &) override;
    void clearHttpCacheCompleted() override;

    void addWebContentsAdapterClient(QtWebEngineCore::WebContentsAdapterClient *adapter) override;
    void removeWebContentsAdapterClient(QtWebEngineCore::WebContentsAdapterClient *adapter) override;

private:
    QWebEngineProfile *q_ptr;
    QWebEngineSettings *m_settings;
    QPointer<QtWebEngineCore::ProfileAdapter> m_profileAdapter;
    QScopedPointer<QWebEngineScriptCollection> m_scriptCollection;
    QMap<quint32, QPointer<QWebEngineDownloadRequest>> m_ongoingDownloads;
    std::function<void(std::unique_ptr<QWebEngineNotification>)> m_notificationPresenter;
};

QT_END_NAMESPACE

#endif // QWEBENGINEPROFILE_P_H
